/* ZGV v2.0 - (c) 1993,1994 Russell Marks for improbabledesigns.
 * See README for license details.
 *
 * rc_config.h - Defined! the zgv_config structure.
 *                       photographic evidence on page 2. :)
 */

struct zgv_config {
  int videomode,zoom,vkludge,jpeg24bit;
  int centreflag,blockcursor,thicktext;
  int betterpgm;  /* grinds PGM to 24-bit internally allowing 256 shades */
  int hicolmodes;	/* force zgv to think card has high-colour modes */
  int nodelprompt,perfectindex;
  int xvpic_index;
  int onefile_progress,cleartext;
  
  int brightness;
  double contrast;
  int black_r,black_g,black_b;
  int dark_r,dark_g,dark_b;
  int medium_r,medium_g,medium_b;
  int light_r,light_g,light_b;
  int mode_allowed[256];
  };
